FUNCTION mtele2,d

; Calculation of 2-D theoretical MTF of a diffraction-limited telescope.
; calling:   RESULT = MTELE2(d)

; PARAMETERS ------------------------------------------------------------

	STP=0.054   ;0.06218     ; STEP OF RESTORED IMAGES (arcsec/pix)
	lambda=4.45045d-5 ;5.250d-5   ; WORKING WAVELENGTH (cm)
	n=1024  ;512       ; SIZE (pixels in x,y) OF ARRAY - only powers of 2
;	d=50.		  ; DIAMETER OF THE TELESCOPE (cm)

; 1-D calculation -------------------------------------------------------

t1=dblarr(n)
c=lambda*2.06265d5/(d*n*STP)
ss=0

   for i=1,n do begin
	      
      omega=c*(i-1)
      if omega lt 1.d0 then begin
        TT=acos(omega)-omega*sqrt(1.-omega^2)
      endif else begin
        ss=ss+1
	if ss eq 1 then print,'cutoff: ',i-1
	TT=0.d0
      endelse
      t1(i-1)=2.*TT/3.141592654d0

   endfor

t1=float(t1)

; transition to 2-D -----------------------------------------------------

t=fltarr(n,n)
f1=fltarr(n/2+1,n/2+1)

cros0=min(where(t1 le 0))		; zero crossing point of t1,
					; i.e. we can compute only
for j=0,cros0 do begin			; the non-zero part. The rest
	for i=0,cros0 do begin		; are zeros by definition.
		ii=float(i)
		jj=float(j)
		r=sqrt(ii*ii+jj*jj)
		r1=fix(r)
		if r1 ge cros0 then begin
		  f1(i,j)=0.
		endif else begin
		  f1(i,j)=t1(r1)+(t1(r1+1)-t1(r1))*(r-r1)
		endelse
	endfor
endfor

f2=reverse(f1(1:n/2-1,*),1)

t(0:n/2,0:n/2)=f1
t(n/2+1:n-1,0:n/2)=f2
t(n/2+1:n-1,n/2+1:n-1)=reverse(f2(*,1:n/2-1),2)
t(0:n/2,n/2+1:n-1)=reverse(f1(*,1:n/2-1),2)

RETURN,t
END
