PRO correli2,day

; Matching (registering) pairs of images taken simultaneously 
; in two different wavelength bands. "GC" images are taken
; as a reference, "C6" images are:
; 1. rotated and re-magnified,
; 2. rigidly aligned (shifted) in two steps - coarse and fine,
; 3. warped (destretched).
; Used to process the SST 2003 data.
;
; INPUTS: day = date (16,19,20)
; 	Restored images gc and c6 (*rr*) in sav2 format
;	Logfiles
; OUTPUT: Integer frames c6 (*mm*) in sav2 format,
;	  numbered according to logfile
;
; Routines called: NINT, RESTORE2, SPC, SAVE2, ALIGN_C2, DEFORMO,
;	SMOOTHE, DISTORTI, SCONVOL, ODD, FIVEPOIN, MAXLOC
;
; 23 March 2004, Michal
;
on_error,1

; PARAMETERS: =================================================

angle = (-0.48)		; rotation angle (degrees)
magn  = 0.997		; magnification
pivx  = 512		; pivot-point coords (image centre)
pivy  = 512

ac0   = 384		; corners of square alignment window (pixels)
ac1   = 640
aws   = 192		; window size (pix) for ALIGN_C2 - here,
			;  ac1-ac0-aws = 64, => 31-pix.shift possible
smo   = 25		; unsharp-masking parameters for DEFORMO
umq   = 0.5		;  (25 pix ~ 1")
fwhm  = 42		; 1.7" correl. window for DEFORMO
reb   = 2		; rebinning factor for DEFORMO

; PATHS AND NAMES =============================================

sday=strtrim(fix(day),2)
dsday=sday
if day eq 19 then begin
  print,'Process series (s) or single frames (other keys) ?'
  if get_kbrd(1) eq 's' then dsday='19ser'
endif

pa1='/home/msobotka/data/sst03/'
pagc='gc_'+dsday+'/'
pac6='c6_'+dsday+'/'
figc='gc_'+sday+'rr.'	; input gc
fic6='c6_'+sday+'rr.'	; input c6
foc6='c6_'+sday+'mm.'	; output c6

; read logfile
logname=findfile(pa1+pagc+'*lg*.sav2')
restore2,logname,logarr,/swap
nfr=(size(logarr))(2)
print,'Number of frames:',nfr

; ============================================================

; Loop over frames

for i=0,nfr-1 do begin

  num=string(fix(logarr(0,i)),format='(I4.4)')	;frame number
  ut=logarr(1,i)				;time UT

; Time-dependent coarse y-shifts 'cs' in pix
;  (SST differential refraction)

  case 1 of
	ut le 9. : 			cs=(-40)
	(ut gt 9.) and (ut le 12.) : 	cs=(-20)
	ut gt 12.: 			cs = 0
  endcase

; Reading images
  restore2,pa1+pagc+figc+num,gc
  restore2,pa1+pac6+fic6+num,c6

; Rotation and re-magnification
  c6r=ROT(c6,angle,magn,pivx,pivy,cubic=(-0.5),/pivot)

; Coarse shift
  c6r=SHIFT(c6r,0,cs)

; Fine shift
  offs=ALIGN_C2(gc(ac0:ac1,ac0:ac1),c6r(ac0:ac1,ac0:ac1),flg,aws,aws)
  if flg ne 0 then goto,skip	; bad correlation, do not store
  offs=NINT(offs)
  c6r=SHIFT(c6r,offs(0),offs(1))

; Warping (destretching)
  DEFORMO,c6r,gc,c6m,smo,umq,fwhm,reb,interp=(-0.5)

; Storing processed image c6m (save2)
  save2,pa1+pac6+foc6+num,c6m
  print,'Stored ',foc6+num,i

  skip:
endfor

END

