PRO get_best,day,type
;
; Flatfielded and normalized frames are selected according to a
; given criterion, best frames are copied to the directory "images_best"
; and a new logfile type_day'lgbest' with these frames is made.
; INPUTS: day   = date (14,16,18,19,20)
;	  type  = channel ('gc' or 'ca')
;	  '*selg' logfile (0 - seq. no., 1 - UT, 2 - SST sharpness, 5 - contrast) 
; OUTPUT: *lgbest.sav2 and *lgbest.txt files with the new logfile
; NOTE: Since 'gc' is the master, 'c6' frames are processed
;	simultaneously with 'gc'
; SUBROUTINE: wrilogtxt, bighair

sday=strtrim(fix(day),2)

;paths and names

pa1='/scratch1/sobotka/lap2003/images_ffn/'
pa2=type+'_'+sday+'/'
rejpa='/scratch1/sobotka/lap2003/images_best/'

lgfil=pa1+pa2+type+'_'+sday+'selg.sav2'	;original logfile
selgfil=rejpa+pa2+type+'_'+sday+'lgbest'	;new logfile
fil=pa1+pa2+type+'_'+sday+'ffn.'	;frame name

if type eq 'c6' then goto,fin
restore2,lgfil,log			;read orig. logfile

if day eq 19 and type eq 'gc' then log=log(*,521:*)	;exclude series

nr=0					;nr = no. of selected frames

if type eq 'gc' then begin
  c6fil=pa1+'c6_'+sday+'/c6_'+sday+'ffn.'
  c6lgfil=pa1+'c6_'+sday+'/c6_'+sday+'selg.sav2'
  c6selgfil=rejpa+'c6_'+sday+'/c6_'+sday+'lgbest'
endif

; set criterion = minimum SST sharpness

window,0,xs=1000		;quality plot
plot,log(0,*),log(2,*),xtitle='Frame',ytitle='SST Sharpness'

select:

bighair
print,''
read,' Lower limit of sharpness: ',cri
  ; SST sharpness > cri
    w   =where((log(2,*) gt cri),nr)
    
print,' Selected:',nr
if nr eq 0 then goto,fin	;no selected frames
plot,log(0,*),log(2,*),xtitle='Frame',ytitle='SST Sharpness'
oplot,log(0,w),log(2,w),psym=6
print,'**** OK ? (y/n) ****'
if get_kbrd(1) ne 'y' then goto,select

; LOOP over frames - copying best ones to images_best/type_sday/

for i=0,nr-1 do begin

  stnum = string(fix(log(0,w(i))),format='(I4.4)')
  print,' Copying  ',stnum,'  to images_best/'
  
  if type eq 'gc' then begin
      str1='cp '+fil+stnum+' '+rejpa+pa2
      spawn,str1
      str2='cp '+c6fil+stnum+' '+rejpa+'c6_'+sday+'/'
      spawn,str2
  endif

  if type eq 'ca' then begin    
      str='cp '+fil+stnum+' '+rejpa+pa2
      spawn,str
  endif

endfor

; END_OF_LOOP

; Making new logfile(s)

if type eq 'gc' then begin
  newlog=log(*,w)
  restore2,c6lgfil,c6log
  if day eq 19 then c6log=c6log(*,521:*)	;exclude series
  newc6log=c6log(*,w)
  print,' Writing new logfile: ',selgfil
  print,' Writing new logfile: ',c6selgfil
  wrilogtxt,selgfil,newlog
  wrilogtxt,c6selgfil,newc6log
endif

if type eq 'ca' then begin
  newlog=log(*,w)
  print,' Writing new logfile: ',selgfil
  wrilogtxt,selgfil,newlog
endif

; Check if new logs are ok
plot,log(0,*),log(2,*),psym=1,symsiz=0.5,xtitle='Frame',ytitle='SST Sharpness'
oplot,newlog(0,*),newlog(2,*),psym=6,symsiz=0.8

fin:
print,' DONE'
END
