PRO stray_match,day,type,cs,xshift
;
; Extraction of 1024x1024 subfield matching roughly in gc and c6.
; Correction for scattered light.
;
; INPUTS: day   = date (14,16,18,19,20)
;	  type  = channel ('gc', 'c6')
;	  cs    = contamination by stray light = 1-c or (1-c)/2
;	  xshift= shift in x to center the object
;	Flatfielded (*ffn*) images in sav2 format, normalized to 10000
;	Logfiles
;
; OUTPUT: Integer 1024x1024 frames (*pp*) in sav2 format,
;	  numbered according to logfile
;

on_error,1

csn=cs*10000.

sday=strtrim(fix(day),2)
dsday=sday
if day eq 19 then begin
  print,'Process series (s) or single frames (other keys) ?'
  if get_kbrd(1) eq 's' then dsday='19ser'
endif
pa1='/home/msobotka/data/sst03/'
pa2=type+'_'+dsday+'/'		;paths
ofil=type+'_'+sday+'pp.'	;output name

; read logfile
logname=findfile(pa1+pa2+'*lg*.sav2')
restore2,logname,log,/swap
n=(size(log))(2)
print,'Number of frames:',n

; loop over frames

for i=0,n-1 do begin

  num=string(fix(log(0,i)),format='(I4.4)')	;frame number
  name=findfile(pa1+pa2+'*.'+num)
  if (size(name))(1) ne 1 then message,' !!! file not found !!!'
  restore2,name,im,/swap

  if type eq 'gc' then begin
	im=im(61+xshift:1084+xshift,4:1027)
  endif else begin
	im=rotate(im,5)		;flip horizontally c6
	im=im(1+xshift:1024+xshift,4:1027)
  endelse

  im=(im-csn)/(10000-csn)	;stray light correction
  im=nint(im*10000)

  print,'Storing: ',pa2+ofil+num,i+1
  save2,pa1+pa2+ofil+num,im

endfor

END


